@@ -787,12 +787,12 @@ def TamilNaToNNa(Strng):
     Strng = re.sub('('+ListV+')'+ GM.VedicSvaras + '('+na+')' + '(?!' + vir + ')',r'\1\2'+nna,Strng)
     Strng = re.sub('('+ListV+')'+ GM.VedicSvaras + '('+na+')' + '(?!' + vir + ')',r'\1\2'+nna,Strng)
 
-    #Strng = re.sub('(ந்)(?!த)', 'ன்', Strng)
-
     Strng = re.sub('(²|³|⁴)'+'('+na+')',r'\1'+nna,Strng)
+    Strng = Strng.replace(na+vir,nna+vir)
     Strng = Strng.replace(nna+vir+ta,na+vir+ta)
 
     Strng = re.sub('(\s)(ன)', r'\1' + 'ந', Strng)
+    Strng = re.sub('(\.)(ன)', r'\1' + 'ந', Strng)
     Strng = re.sub('^ன', 'ந', Strng)
 
     Strng = re.sub("(?<=ஶ்ரீ)(ன)(?!" + vir + ")", "ந", Strng)
